﻿<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
	<xsl:key name="task_day_key" match="//DAY" use="PLANENTRY/@TASKID"/>
	<xsl:template match="/">
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<HTML>
			<HEAD>
				<META NAME="Report" CONTENT="{CompletedTasks}"/>
				<TITLE>{Report}: {CompletedTasks} {OfTheProject} &quot;<xsl:value-of select="$projectTitle"/>&quot;</TITLE>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
			<H2>{CompletedTasks}</H2>
			
			<xsl:for-each select="//PROPERTIES">
			<table border="0" cellpadding="2" cellspacing="0">
				<tr>
				<td class="righttitle">{Employee}: </td>
				<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
				</tr>
				<tr>
				<td class="righttitle">{Category}: </td>
				<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
				</tr>
			</table>
			</xsl:for-each>
			
			<br/>

			<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
			<THEAD style="display: table-header-group"> 
			<TR>
			<TD class="leftHeadCell">{Name}</TD>
			<TD class="headCell">{Description}</TD>
			<TD class="headCell">{OriginalEstimation} ({hours})</TD>
			<TD class="headCell">{TimeSpent} ({hours})</TD>
			<TD class="headCell">{ActualUnderSpend} (hours)</TD>
			<TD class="headCell">{CompletedAt}</TD>
			</TR>
			</THEAD>
			<TBODY>
			<xsl:choose>
			<xsl:when test="$AffectedCategory != 0">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="vb:SetBaseIntend(vb:GetIntend(.))"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
			<xsl:for-each select="ROOT/CATEGORY">
				<xsl:value-of select="vb:SetBaseIntend('')"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			</xsl:otherwise>
			</xsl:choose>
			</TBODY>
			</TABLE>
			
			<BR/>
			<table border="0" cellpadding="2" cellspacing="0">
			<tr><td colspan="2">&#160; </td></tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell">{ManagerSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			</table>
			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="CATEGORY">
		<xsl:variable name="categoryId" select="@ID"/>
		<xsl:variable name="estimatesCat" select="sum(.//TASK[@STATUS=2]/@ESTIMATION)"/>
		<xsl:variable name="originalEstimatesCat" select="sum(.//TASK[@STATUS=2]/@ORIGINALESTIMATION)"/>
		<xsl:variable name="catPlanEntriesList" select="//DAY/PLANENTRY[@TASKID=//CATEGORY[@ID=$categoryId]//TASK[@STATUS=2]/@ID]"/>
		<xsl:variable name="stageWorkingHours" select="vb:CalculateHours($catPlanEntriesList)"/>
		<xsl:variable name="catPlanEntriesDaysList" select="//DAY[PLANENTRY/@TASKID=//CATEGORY[@ID=$categoryId]//TASK[@STATUS=2]/@ID]"/>
		<xsl:variable name="catLastPlanEntryDate" select="vb:GetLastPlanEntryDate($catPlanEntriesDaysList)"/>
		<TR>
			<TD class="categoryCell">
				<xsl:value-of select="vb:GetIntend(.)"/>
				<xsl:value-of select="@NAME"/>
			</TD>
			<TD class="categoryDescription">
				<xsl:value-of select="vb:RestrictLength(string(DESCRIPTION), 110)"/>&#160;
			</TD>
			<TD class="categoryTotal">
				<xsl:value-of select="vb:FormatNumberEx(js:ToDbl($originalEstimatesCat))"/>
			</TD>
			<TD class="categoryTotal">
				<xsl:value-of select="vb:FormatNumberEx($stageWorkingHours)"/>
			</TD>
			<TD class="categoryTotal">
				<xsl:value-of select="vb:Substract($stageWorkingHours, 
$originalEstimatesCat)"/>
			</TD>
			<TD class="categoryTotal">
				<xsl:if test="not(.//TASK/@STATUS &lt; 2)">
					<xsl:value-of select="vb:FormatDate($catLastPlanEntryDate)"/>
				</xsl:if>&#160;
			</TD>
		</TR>
		
		<xsl:if test="./TASK[@STATUS=2]">
			<xsl:for-each select="./TASK">
				<xsl:sort select="@NAME"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:if>
		<xsl:if test="./CATEGORY">
			<xsl:if test=".//TASK[@STATUS=2]">
				<xsl:for-each select="./CATEGORY">
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="TASK">
	<xsl:if test="@STATUS=2">
		<xsl:variable name="id" select="@ID"/>
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', $id)"/>
		<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
		<xsl:variable name="timeSpent" select="vb:CalculateHours($planEntriesList)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>	
		<xsl:if test="$nPlanEntries&gt;0">
			<xsl:variable name="lastPlanEntryDate" select="vb:GetLastPlanEntryDate($planEntriesDaysList)"/>
			<TR>
			<TD class="taskCell">
				<xsl:value-of select="vb:GetRecentIntend()"/><xsl:value-of select="@NAME"/>
			</TD>
			<TD class="taskDescription">
				<xsl:value-of select="vb:RestrictLength(string(DESCRIPTION), 110)"/>&#160;
			</TD>
			<TD class="freeTableCell"><xsl:if test="string(@ORIGINALESTIMATION)!=''"><xsl:value-of 
			select="vb:FormatNumberEx(js:ToDbl(string(@ORIGINALESTIMATION)))"/></xsl:if><xsl:if 
			test="string(@ORIGINALESTIMATION)=''">{Unplanned}</xsl:if></TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:FormatNumberEx($timeSpent)"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:Substract($timeSpent, js:ToDbl(string(@ORIGINALESTIMATION)))"/>
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:FormatDate($lastPlanEntryDate)"/>
			</TD>
			</TR>
		</xsl:if>
	</xsl:if>
	</xsl:template>

</xsl:stylesheet>
