<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="ReportingPeriodStart"/>
	<xsl:param name="ReportingPeriodEnd"/>
	<xsl:param name="Is24HoursFormat"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="DayTimeProcessing.inc"/>
	<xsl:include href="HolidaysProcessing.inc"/>
	<xsl:include href="TimeSheetProcessing.inc"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>
	<xsl:template match="/">
		<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
		<xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
		<xsl:value-of select="vb:SetTimeFormat($Is24HoursFormat)"/>
		<HTML>
			<HEAD>
				<TITLE>{Report}: {MoodsMap} (<xsl:value-of select="vb:FormatThisPeriod()"/>)</TITLE>
				<META NAME="Report" CONTENT="{MoodsMap}"/>
				<STYLE ID="ReportStyle">
					<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="2">
						<tr>
							<td valign="top">
								<table width="100%" border="0" class="headingtable">
									<tr>
										<td class="righttitle">{Name}: </td>
										<td class="employee"><xsl:value-of select="@AUTHOR"/></td>
									</tr>
									<tr>
										<td class="righttitle">{ReportingPeriod}: </td>
										<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
									</tr>
									<tr>
										<td colspan="2" class="emptyrow"></td>
									</tr>
								</table>
							</td>
						</tr>
						<tr><td colspan="2" class="doctitle">{MoodsMap}</td></tr>
					</table>
				</xsl:for-each>
				<TABLE BORDER="0" CELLPADDING="0" CELLSPACING="0">
					<THEAD style="display: table-header-group">
						<TR>
							<TD>&#160;</TD>
							<xsl:value-of select="vb:ResetStart()"/>
							<xsl:for-each select="ms:node-set($weekDaysList)/IT">
								<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
									<TD WIDTH="80" ALIGN="Center">
										<xsl:call-template name="HolidayColoring">
											<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
											<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
										</xsl:call-template>
										<xsl:value-of select="vb:ToWeekDayName(vb:GetDaysIteratorString())"/>
									</TD>
								</xsl:if>
								<xsl:value-of select="vb:MoveNextDay()"/>
							</xsl:for-each>
						</TR>
					</THEAD>
					<xsl:call-template name="AllDays">
						<xsl:with-param name="currentContext" select="/"/>
					</xsl:call-template>
				</TABLE>

<P><B>Legend:</B></P>
				<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="4">
					<xsl:for-each select="//AVAILABLEMOODS/MOOD">
					<TR>
					<TD WIDTH="10"><xsl:attribute name="BGCOLOR">#<xsl:value-of select="@COLOR"/></xsl:attribute>&#160;</TD>
					<TD><xsl:value-of select="@NAME"/></TD>
					</TR>
					</xsl:for-each>
				</TABLE>

			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template name="AllDays">
		<xsl:param name="currentContext"/>
		<TBODY>
			<TR>
				<TD VALIGN="top">
				<xsl:call-template name="DayHours"/>
				</TD>
				<xsl:value-of select="vb:ResetStart()"/>
				<xsl:for-each select="ms:node-set($weekDaysList)/IT">
					<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
						<TD VALIGN="top">
							<xsl:call-template name="MoodsForDay">
								<xsl:with-param name="dayIterator"><xsl:value-of select="vb:GetDaysIteratorString()"/></xsl:with-param>
								<xsl:with-param name="currentContext" select="$currentContext"/>
							</xsl:call-template>
						</TD>
					</xsl:if>
					<xsl:value-of select="vb:MoveNextDay()"/>
				</xsl:for-each>
			</TR>
		</TBODY>
	</xsl:template>

	<xsl:template name="MoodsForDay">
		<xsl:param name="dayIterator"/>
		<xsl:param name="currentContext"/>
		<table border="0" cellspacing="0" cellpadding="0">
		<xsl:value-of select="vb:ResetColors()"/>
		<xsl:for-each select="ms:node-set($currentContext)//MOODSDAILY/DAY[vb:IsEqualDate(string(@DATE), string($dayIterator))]/MOODSTATE">
			<xsl:variable name="moodId" select="@MOODID"/>
			<xsl:variable name="startTime" select="@STARTTIME"/>
			<xsl:variable name="color" select="ms:node-set($currentContext)//MOOD[@ID=$moodId]/@COLOR"/>
			<xsl:variable name="height" select="vb:GetNextHeight(string($startTime))"/>
			<xsl:if test="$height &gt; 0">
				<tr><td width="80">
				<xsl:attribute name="BGCOLOR">#<xsl:value-of select="vb:GetPreviousColor()"/></xsl:attribute>
				<xsl:attribute name="height"><xsl:value-of select="$height"/></xsl:attribute>
				</td></tr>
			</xsl:if>
			<xsl:value-of select="vb:SetNextColor(string($color))"/>
		</xsl:for-each>
				<tr><td width="80" height="15">
				<xsl:attribute name="BGCOLOR">#<xsl:value-of select="vb:GetPreviousColor()"/></xsl:attribute>
				</td></tr>
		</table>
	</xsl:template>

	<xsl:template name="HolidayColoring">
		<xsl:param name="defaultColor"/>
		<xsl:param name="holidayColor"/>
		<xsl:attribute name="BGCOLOR">
			<xsl:choose>
				<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
	<xsl:template name="DayHours">
	<xsl:value-of select="vb:ResetTimeStart(8)"/>
	<table border="0" cellspacing="0" cellpadding="0">
		<xsl:for-each select="ms:node-set($dayHoursList)/IT">
			<tr><td colspan="2" valign="top" height="30" class="timeCell"><xsl:value-of select="vb:GetHoursIteratorString()"/></td></tr>
			<tr><td width="10">&#160;</td><td valign="top" height="30" class="timeCell">&#160;<!--<xsl:value-of select="vb:GetHalfHoursIteratorString()"/>--></td></tr>
			<xsl:value-of select="vb:MoveNextHour()"/>
		</xsl:for-each>
	</table>
	</xsl:template>
</xsl:stylesheet>
