<?xml version='1.0'?>

<xsl:stylesheet 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:ms="urn:schemas-microsoft-com:xslt"
xmlns:vb="urn:the-xml-files:xslt-vb"
xmlns:js="urn:the-xml-files:xslt-js"
version="1.0">
<xsl:output method="html"/>
<xsl:param name="ReportingPeriodStart"/>
<xsl:param name="ReportingPeriodEnd"/>
<xsl:param name="RegularHours"/>
<xsl:param name="Is24HoursFormat"/>
<xsl:include href="WeekProcessing.inc"/>
<xsl:include href="PlanEntryProcessing.inc"/>
<xsl:include href="HolidaysProcessing.inc"/>
<xsl:include href="Common.inc"/>
<xsl:include href="TimeSheetProcessing.inc"/>
<xsl:include href="ReportCSS.inc"/>

<xsl:key name="day_key" match="//DAY" use="@DATE"/>

<xsl:template match="/">
  <xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
  <xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
  <xsl:value-of select="vb:SetRegularHours($RegularHours)"/>
  <xsl:value-of select="vb:SetTimeFormat($Is24HoursFormat)"/>
<html>
<head>
<title>{WeeklyEmployeeTimeSheet}</title>
<META NAME="Report" CONTENT="{WeeklyTimeSheet}"/>
<STYLE ID="ReportStyle">
<xsl:value-of select="$css"/>
</STYLE>
</head>
<body>

<xsl:for-each select="//PROPERTIES">

<table border="0" cellpadding="2" cellspacing="2">
<tr><td colspan="2" class="company"><xsl:value-of select="@COMPANY"/></td></tr>
  <tr> 
    <td width="270" class="addr">
    <pre><xsl:value-of select="ADDRESS"/></pre></td>
    <td valign="top">
	<table width="100%" border="0" class="headingtable">
	<tr>
	<td class="righttitle">{EmployeeName}: </td>
	<td class="employee"><xsl:value-of select="@AUTHOR"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{ManagerName}: </td>
	<td class="underlined"><xsl:value-of select="@MANAGER"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{WeekStarting}: </td>
	<td class="underlined"><xsl:value-of select="vb:FormatDate($ReportingPeriodStart)"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	</table>
  </td>
  </tr>
  <tr><td colspan="2" class="doctitle">{WeeklyEmployeeTimeSheet}</td></tr>
</table>
</xsl:for-each>

<br/>
<table border="0" cellpadding="2" cellspacing="0">
<thead>
<tr>
<td class="noBorderHeadCell" style="width: 90">{DayOfWeek}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Time}<br/>{In}</span></td>
<td class="noBorderHeadCell"><span class="tableHeads">{Time}<br/>{Out}</span></td>
<td class="noBorderHeadCell">{Meal}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Time}<br/>{In}</span></td>
<td class="noBorderHeadCell"><span class="tableHeads">{Time}<br/>{Out}</span></td>
<td class="noBorderHeadCell">{Total}<br/>{Hrs}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Regular}</span><br/>{Hrs}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Overtime}</span><br/>{Hrs}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Sick}</span><br/>{Hrs}</td>
<td class="noBorderHeadCell"><span class="tableHeads">{Vacation}</span><br/>{Hrs}</td>
</tr>
</thead>
<tbody>

<xsl:call-template name="DayHours">
  <xsl:with-param name="docContext" select="/"/>
</xsl:call-template>

<tr>
<td colspan="7" class="totalNameCell">{Total}:</td>
<td class="noBorderTotalCell"><xsl:value-of select="vb:GetRegularHoursTotal()"/>&#160; </td>
<td class="noBorderTotalCell"><xsl:value-of select="vb:GetOvertimeTotal()"/>&#160; </td>
<td class="noBorderTotalCell"><xsl:value-of select="vb:GetSickHoursTotal()"/>&#160; </td>
<td class="noBorderTotalCell"><xsl:value-of select="vb:GetVacationHoursTotal()"/>&#160; </td>
</tr>
</tbody>
</table>
<br/>

<table border="0" cellpadding="2" cellspacing="0">
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell">{ManagerSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
</table>
</body>
</html>
</xsl:template>

<xsl:template name="DayHours">
<xsl:param name="docContext"/>

<xsl:value-of select="vb:ResetStart()"/>
<xsl:for-each select="ms:node-set($weekDaysList)/IT">
  <xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
  
  <xsl:for-each select="ms:node-set($docContext)">
  <xsl:variable name="planEntries" select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY"/>
  <xsl:variable name="mealTaskId" select="//TASK[@NAME='Meal']/@ID"/>
  <xsl:variable name="sickTaskId" select="//TASK[@NAME='Sick']/@ID"/>
  <xsl:variable name="vacationTaskId" select="//TASK[@NAME='Vacation']/@ID"/>
  <xsl:value-of 
  select="vb:SetFirstEntryStart(string(ms:node-set($planEntries)[1]/@STARTTIME))"/>
  <xsl:value-of 
  select="vb:SetLastEntryEnd(string(ms:node-set($planEntries)[last()]/@ENDTIME))"/>
  <xsl:value-of 
  select="vb:SetMealStart(string(ms:node-set($planEntries)[@TASKID=$mealTaskId]/@STARTTIME))"/>
  <xsl:value-of 
  select="vb:SetMealEnd(string(ms:node-set($planEntries)[@TASKID=$mealTaskId]/@ENDTIME))"/>
  <xsl:value-of 
  select="vb:SetSickEnd(string(ms:node-set($planEntries)[@TASKID=$sickTaskId]/@ENDTIME))"/>
  <xsl:value-of 
  select="vb:SetSickStart(string(ms:node-set($planEntries)[@TASKID=$sickTaskId]/@STARTTIME))"/>
  <xsl:value-of 
  select="vb:SetVacationStart(string(ms:node-set($planEntries)[@TASKID=$vacationTaskId]/@STARTTIME))"/>
  <xsl:value-of 
  select="vb:SetVacationEnd(string(ms:node-set($planEntries)[@TASKID=$vacationTaskId]/@ENDTIME))"/>
<tr>
<td class="dayCell"><xsl:value-of select="vb:ToWeekDayOnly(vb:GetDaysIteratorString())"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetFirstTimeIn()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetFirstTimeOut()"/></td>
<td class="intermCell">&#160;</td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetSecondTimeIn()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetSecondTimeOut()"/></td>
<td class="intermCell">&#160;<xsl:value-of select="vb:GetTotalHours()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetRegularHoursWorked()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetOvertime()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetSickHours()"/></td>
<td class="tableCell">&#160;<xsl:value-of select="vb:GetVacationHours()"/></td>
</tr>

</xsl:for-each>
  </xsl:if>
  <xsl:value-of select="vb:MoveNextDay()"/>
</xsl:for-each>

</xsl:template>

</xsl:stylesheet>