<?xml version='1.0'?>
<xsl:stylesheet 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:ms="urn:schemas-microsoft-com:xslt"
xmlns:vb="urn:the-xml-files:xslt-vb"
xmlns:js="urn:the-xml-files:xslt-js"
version="1.0">
<xsl:output method="html"/>
<xsl:param name="AffectedCategory"/>
<xsl:param name="ReportingPeriodStart"/>
<xsl:param name="ReportingPeriodEnd"/>
<xsl:include href="Common.inc"/>
<xsl:include href="WeekProcessing.inc"/>
<xsl:include href="PlanEntryProcessing.inc"/>
<xsl:include href="HolidaysProcessing.inc"/>
<xsl:include href="Intending.inc"/>
<xsl:include href="ReportCSS.inc"/>

<xsl:key name="task_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>

<xsl:template match="/">
  <xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
  <xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>

<HTML>
<HEAD>
<TITLE>{Report}: {WeeklyWorkReview} (<xsl:value-of select="vb:FormatThisPeriod()"/>)</TITLE>
<META NAME="Report" CONTENT="{WeeklyWorkReview}"/>
<STYLE ID="ReportStyle">
<xsl:value-of select="$css"/>
</STYLE>
</HEAD>
  <BODY>

<xsl:for-each select="//PROPERTIES">
<table border="0" cellpadding="2" cellspacing="2">
<tr><td colspan="2" class="company"><xsl:value-of select="@COMPANY"/></td></tr>
  <tr> 
    <td width="270" class="addr">
    <pre><xsl:value-of select="ADDRESS"/></pre></td>
    <td valign="top">
	<table width="100%" border="0" class="headingtable">
	<tr>
	<td class="righttitle">{EmployeeName}: </td>
	<td class="employee"><xsl:value-of select="@AUTHOR"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{ManagerName}: </td>
	<td class="underlined"><xsl:value-of select="@MANAGER"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{ReportingPeriod}: </td>
	<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	</table>
  </td>
  </tr>
  <tr><td colspan="2" class="doctitle">{WeeklyWorkReview}</td></tr>
</table>
</xsl:for-each>

    <TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0">
	<THEAD style="display: table-header-group">
      <TR>
        <TD class="leftHeadCell">{Task}</TD>
        <xsl:value-of select="vb:ResetStart()"/>
        <xsl:for-each select="ms:node-set($weekDaysList)/IT">
        	<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
        		<TD class="headCell">
        		<xsl:call-template name="HolidayColoring">
        		<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
        		<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
        		</xsl:call-template>
        		<xsl:value-of select="vb:ToWeekDayName(vb:GetDaysIteratorString())"/></TD>
        	</xsl:if>
        	<xsl:value-of select="vb:MoveNextDay()"/>
        </xsl:for-each>
        <TD class="headCell">{Tot}</TD>
      </TR>
	</THEAD>
	<TBODY>

    <xsl:choose>
      <xsl:when test="$AffectedCategory != 0">
        <xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
          <xsl:sort select="@NAME"/>
          <xsl:value-of select="vb:SetBaseIntend(vb:GetIntend(.))"/>
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="ROOT/CATEGORY">
          <xsl:sort select="@NAME"/>
          <xsl:value-of select="vb:SetBaseIntend('')"/>
          <xsl:apply-templates select="."/>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
    
	<!--<xsl:for-each select="ROOT/CATEGORY">
		<xsl:sort select="@NAME"/>
		<xsl:apply-templates select="."/>
	</xsl:for-each>-->

      <TR>
          <TD class="leftTotalCell">{DailyTotals}</TD>

          <xsl:call-template name="DailyTotals">
          <xsl:with-param name="currentContext" select="/"/>
          </xsl:call-template>
          
          <TD class="totalCell"><xsl:value-of select="vb:GetWeeklyWorkingHours()"/></TD>
        </TR>
	</TBODY>
    </TABLE>

<br/>

<table border="0" cellpadding="2" cellspacing="0">
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell">{ManagerSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
</table>

  </BODY>
</HTML>
</xsl:template>

<xsl:template match="CATEGORY">

	<xsl:variable name="planEntriesListCat" select="key('task_key', .//TASK/@ID)"/>
	<xsl:variable name="nPlanEntriesCat" select="count($planEntriesListCat)"/>
	<xsl:variable name="workingHoursCat" select="vb:CalculateHours($planEntriesListCat)"/>
	<xsl:if test="$nPlanEntriesCat>0">

	<TR>
        <TD class="categoryCell">
        <xsl:attribute name="COLSPAN"><xsl:value-of select="vb:GetDaysNumber()+1"/></xsl:attribute>
        <xsl:value-of select="vb:GetIntend(.)"/><xsl:value-of select="@NAME"/></TD>
        <TD class="categoryTotal"><B><xsl:value-of select="$workingHoursCat"/></B></TD>
    </TR>

	<xsl:if test="./TASK">
		<xsl:for-each select="./TASK">
			<xsl:sort select="@NAME"/>
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:if>

	<xsl:if test="./CATEGORY">
		<xsl:for-each select="./CATEGORY">
			<xsl:sort select="@NAME"/>
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:if>
	
  </xsl:if>
</xsl:template>

<xsl:template match="TASK">
	<xsl:variable name="id" select="@ID"/>
	<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
	<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>
	<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
	<xsl:if test="$nPlanEntries>0">
        <TR>
          <TD class="taskCell"><xsl:value-of select="vb:GetRecentIntend()"/>
          <xsl:value-of select="@NAME"/></TD>
          
          <xsl:call-template name="TaskHours">
          <xsl:with-param name="currentContext" select="/"/>
          <xsl:with-param name="id" select="$id"/>
          </xsl:call-template>
          
          <TD class="taskTotalCell"><xsl:value-of select="$workingHours"/></TD>
        </TR>
      </xsl:if>
</xsl:template>

<xsl:template name="TaskHours">
	<xsl:param name="currentContext"/>
	<xsl:param name="id"/>
	<xsl:value-of select="vb:ResetStart()"/>
	<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
		<xsl:for-each select="ms:node-set($currentContext)">
			<xsl:variable name="daysList"
			select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY[@TASKID=$id]"/>
			<xsl:variable name="dayTaskHours" select="vb:CalculateHoursWONuls($daysList)"/>
			<TD class="tableCell"><xsl:call-template name="HolidayColoring">
			<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
			<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
			</xsl:call-template>
			&#160;<xsl:value-of select="vb:AddDayTaskHours($dayTaskHours)"/></TD>
		</xsl:for-each>
		</xsl:if>
		<xsl:value-of select="vb:MoveNextDay()"/>
	</xsl:for-each>
</xsl:template>

<xsl:template name="DailyTotals">
	<xsl:param name="currentContext"/>
	<xsl:value-of select="vb:ResetStart()"/>
	<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
			<TD class="totalCell">&#160;<xsl:value-of 
        select="vb:AddWeekTotal(vb:GetDayTaskHours())"/></TD>
		<xsl:value-of select="vb:MoveNextDay()"/>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="HolidayColoring">
	<xsl:param name="defaultColor"/>
	<xsl:param name="holidayColor"/>
	<xsl:attribute name="BGCOLOR">
	<xsl:choose>
 		<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
 		<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
 	</xsl:choose>
 	</xsl:attribute>
</xsl:template>

</xsl:stylesheet>